@@ -111,7 +111,10 @@ def bool_to_jsBool(value):
 
 class StackElementNotExist(Exception):
     def __init__(self, *args, **kwargs):  # real signature unknown
-        super().__init__('Соответствие не найдено.')
+        if kwargs.get('message'):
+            super().__init__(kwargs.get('message'))
+        else:
+            super().__init__('Соответствие не найдено.')
 
 
 class MultipleStackElement(Exception):
@@ -257,9 +260,17 @@ class Stack:
     def exists(self, function):
         return len([item for item in self.stack if function(item)]) > 0
 
+    def print_all(self):
+        if self.size() > 0:
+            logger1.warning('====================================dump===========================================================================')
+            for item in self.stack:
+                logger1.warning(item)
+            logger1.warning('====================================end dump=======================================================================')
+
     def find_one(self, function):
         res = self.find(function=function)
         if len(res) == 0:
+            # self.print_all()
             raise StackElementNotExist()
         elif len(res) > 1:
             raise MultipleStackElement()
