@@ -12,7 +12,8 @@ def Messages_view_Fetch(request):
     response = DSResponse(
         request=request,
         data=Messages_view.objects.
-            distinct('id').
+            select_related('user', 'state', 'theme', 'to_whom', 'tma_user', 'importance').
+            # distinct('id').
             filter().
             get_range_rows1(
             request=request,
@@ -21,11 +22,15 @@ def Messages_view_Fetch(request):
         status=RPCResponseConstant.statusSuccess).response
     return JsonResponse(response)
 
+
 @JsonResponseWithException()
 def Messages_view_FetchAdmin(request):
+    _response = DSRequest(request)
+    print(_response.get_criteria())
     response = DSResponse(
         request=request,
         data=Messages_admin_view.objects.
+            select_related('user', 'state', 'theme', 'to_whom', 'importance').
             filter().
             get_range_rows1(
             request=request,
